#
# spec file for package plexus-build-api
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plexus-build-api
Version:        1.2.0
Release:        1.1
Summary:        Plexus Build API
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/sonatype/sisu-build-api
Source0:        https://github.com/codehaus-plexus/%{name}/archive/refs/tags/%{name}-%{version}.tar.gz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  plexus-build-api0
BuildRequires:  plexus-utils
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildArch:      noarch

%description
Plexus Build API

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}
cp -p %{SOURCE1} build.xml

%build
mkdir -p lib
build-jar-repository -s lib \
    atinject \
    org.eclipse.sisu.inject \
    org.eclipse.sisu.plexus \
    plexus/utils \
    plexus/plexus-build-api0 \
    slf4j/api
%{ant} \
  jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/plexus
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/plexus/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/plexus
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/plexus/%{name}.pom
%add_maven_depmap plexus/%{name}.pom plexus/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE

%files javadoc
%license LICENSE
%{_javadocdir}/%{name}

%changelog
* Wed May  1 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 1.2.0
  * Breaking changes
    + change package to org.codehaus.plexus.build
  * New features and improvements
    + Convert to JSR 330 component
    + Bump sisu-maven-plugin from 0.3.5 to 0.9.0.M2
    + Switch to parent 13 and reformat
    + Use a CachingOutputStream when using the build context
    + Reuse plexus-pom action for CI
    + Add README and LICENSE
    + Remove ThreadBuildContext (#51) @laeubi
  * Bug Fixes
    + Store Objects in the DefaultContext in a map
    + Let the DefaultBuildContext delegate to the legacy build-api
- Removed patches:
  * plexus-build-api-javadoc.patch
  * plexus-build-api-utils-3.3.0.patch
    + not needed with this version
* Tue Feb 20 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu May 19 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * plexus-build-api-javadoc.patch
    + fix an error of tag in javadoc
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with source and target levels 8
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * plexus-build-api-utils-3.3.0.patch
    + fix build against plexus-utils 3.3.0
* Fri Mar  8 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of plexus-build-api 0.0.7
- Generate and customize ant build.xml file
